/*******************************************************
********************************************************
 
Autore : Mauro Laurenti
Versione : 1.0
Data : 18/06/2013
 
CopyRight 2013 all rights are reserved


********************************************************
SOFTWARE LICENSE AGREEMENT
********************************************************

The usage of the supplied software imply the acceptance of the following license.

The software supplied herewith by Mauro Laurenti (the Author) is intended for
use solely and exclusively on Microchip PIC Microcontroller (registered mark).
The software is owned by the Author, and is protected under applicable
copyright laws. All rights are reserved.
Any use in violation of the foregoing restrictions may subject the
user to criminal sanctions under applicable laws, as well as to civil liability
for the breach of the terms and conditions of this license.
Commercial use is forbidden without a written acknowledgment with the Author.
Personal or educational use is allowed if the application containing the
following software doesn't aim to commercial use or monetary earning of any kind.

THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE AUTHOR SHALL NOT,
IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.

********************************************************
PURPOSES
********************************************************

miniCOM USB Test Suite

The application starts letting the LEDs blinking in sequence afterward:

 * Pressing S1 will Turn ON LED1
 * Pressing S2 will Turn ON LED2

based on USB programming Framework
 
*******************************************************
*******************************************************/

#include <p18f14k50.h>
#include "delay.h"
#include "delay.c"
#include "PIC18F14K50_config.h"


#define LED_1 LATCbits.LATC6
#define LED_2 LATCbits.LATC4

#define SWITCH_1 PORTAbits.RA3
#define SWITCH_2 PORTCbits.RC0

#define LED_ON 0x01
#define LED_OFF 0x00

void New_High_Priority_ISR_Code();
void New_Low_Priority_ISR_Code();

//*************************************************************
//            Address remapping definitions
//*************************************************************

#define REMAPPED_RESET_VECTOR_ADDRESS            0x1000
#define REMAPPED_HIGH_INTERRUPT_VECTOR_ADDRESS   0x1008
#define REMAPPED_LOW_INTERRUPT_VECTOR_ADDRESS    0x1018
     
//Check the file c018i.c
extern void _startup (void);        


//*************************************************************
//            Interrupt Service Routine remapping
//*************************************************************

#pragma code REMAPPED_RESET_VECTOR = REMAPPED_RESET_VECTOR_ADDRESS
void _reset (void){
	_asm goto _startup _endasm
}

#pragma code REMAPPED_HIGH_INTERRUPT_VECTOR = REMAPPED_HIGH_INTERRUPT_VECTOR_ADDRESS
void Remapped_High_ISR (void) {

	_asm goto New_High_Priority_ISR_Code _endasm
}

#pragma code REMAPPED_LOW_INTERRUPT_VECTOR = REMAPPED_LOW_INTERRUPT_VECTOR_ADDRESS
void Remapped_Low_ISR (void) {

	_asm goto New_Low_Priority_ISR_Code _endasm
}

//*************************************************************
//             Interrupt Service Routine
//*************************************************************

#pragma code HIGH_INTERRUPT_VECTOR = 0x08
void High_ISR (void) {

	_asm goto REMAPPED_HIGH_INTERRUPT_VECTOR_ADDRESS _endasm
}


#pragma code LOW_INTERRUPT_VECTOR = 0x18
void Low_ISR (void) {
	_asm goto REMAPPED_LOW_INTERRUPT_VECTOR_ADDRESS _endasm
}

#pragma code

	
//*************************************************************
//          New Interrupt Service Routines
//*************************************************************	

#pragma interrupt New_High_Priority_ISR_Code
void New_High_Priority_ISR_Code() {
	// High Priority Interrupt Handling
}


#pragma interruptlow New_Low_Priority_ISR_Code
void New_Low_Priority_ISR_Code(){
	// Low Priority Interrupt Handling
}

//*************************************************************
//              main ()
//*************************************************************	
void main (void){

	// Initialize PORTA
	LATA = 0x00; 
 	TRISA = 0xFF;

	// Initialize PORTB
 	LATB = 0x00; 
 	TRISB = 0xFF;

	// Initialize PORTC
 	LATC = 0x00;    	 
 	TRISC = 0b10101111;
        
        // Enable the pins as digital input
 	ANSELbits.ANS4 = 0;
        ANSELHbits.ANS9 = 0;

        setQuartz(48);

        LED_1 = LED_ON;
        delay_ms (500);
        LED_1 = LED_OFF;
        LED_2 = LED_ON;
        delay_ms (500);
        LED_2 = LED_OFF;
        delay_ms (500);
        LED_1 = LED_ON;
        LED_2 = LED_ON;
        delay_ms (500);
        LED_1 = LED_OFF;
        LED_2 = LED_OFF;
        delay_ms (500);
        LED_1 = LED_ON;
        LED_2 = LED_ON;
        delay_ms (500);
        LED_1 = LED_OFF;
        LED_2 = LED_OFF;


	// endless loop
	while (1) {

            LED_1 = ~SWITCH_1;
            LED_2 = ~SWITCH_2;
 	} 	
}